@@ -186,7 +186,7 @@ add_soilgrids <- function(x, soilgrids_path = NULL,
   orimaxdepth = sum(soildf$widths)
   # print(cbind(soildf$widths, oridepths, findepths))
   # Modify total soil depth according to bedrock
-  if(!is.na(depth_to_bedrock)) {
+  if(!is.na(depth_to_bedrock) && (depth_to_bedrock>0)) {
     if(depth_to_bedrock < orimaxdepth) {
       to_remove <- (oridepths >= depth_to_bedrock)
       soildf <- soildf[!to_remove,,drop = FALSE]
@@ -198,7 +198,7 @@ add_soilgrids <- function(x, soilgrids_path = NULL,
     }
   }
   # Modify soil depth
-  if(!is.na(soil_depth)) {
+  if(!is.na(soil_depth) && (soil_depth > 0)) {
     if(full_rock_filling) {
       for(l in 1:nl) {
         mid_point <- oridepths[l] + soildf$widths[l]/2
@@ -276,92 +276,3 @@ modify_soils <- function(x, soil_depth_map = NULL,
   return(sf::st_as_sf(tibble::as_tibble(x)))
 }
 
-#' @rdname soil_parametrization
-#' @param fill_missing Logical flag to fill missing values in key parameters with defaults.
-#' @param check_equal_layers Logical flag to test whether soils have the same number of layers.
-#' @param default_values Vector of default values for locations with missing data.
-#' @export
-check_soils <-function(x, 
-                       check_equal_layers = FALSE,
-                       fill_missing = FALSE,
-                       default_values = c("clay" = 25, "sand" = 25, "bd" = 1.5, "rfc" = 25),
-                       progress = FALSE) {
-  if(!inherits(x, "sf")) cli::cli_abort("'x' should be of class 'sf' ")
-  npoints <- nrow(x)
-  if(!("soil" %in% names(x))) cli::cli_abort("Column 'soil' must be defined.")
-  land_cover_type <- rep("wildland", npoints)
-  if("land_cover_type" %in% names(x)) land_cover_type <- x$land_cover_type 
-  soil_cover <- land_cover_type %in% c("wildland", "agriculture")
-  ntarget <- sum(soil_cover)
-  is_soil <- !unlist(lapply(x$soil, is.null))
-  cli::cli_alert_info(paste0(sum(is_soil & soil_cover), " non-null 'soil' elements out of ", ntarget," wildland/agriculture locations (",round(100*sum(is_soil & soil_cover)/ntarget,1),"%)."))
-  if(sum(is_soil & soil_cover) < sum(soil_cover)) cli::cli_alert_warning(paste0("Soil needs to be defined for: ",sum(soil_cover) - sum(is_soil & soil_cover), " locations (",round(100*(sum(soil_cover) - sum(is_soil & soil_cover))/ntarget,1),"%)."))
-  if(progress) {
-    cli::cli_progress_step("Checking for missing values in key soil parameters")
-    cli::cli_progress_bar("Locations", total = nrow(x))
-  }
-  mis_widths <- 0
-  mis_clay <- 0
-  mis_sand <- 0
-  mis_bd <- 0
-  mis_rfc <- 0
-  widths <- NA
-  unequal_layers <- FALSE
-  rfc_over_100 <- FALSE
-  for(i in 1:npoints) {
-    if(progress) cli::cli_progress_update()
-    if(is_soil[i]) {
-      s <- x$soil[[i]]
-      if(any(is.na(s$widths))) {
-        mis_widths <- mis_widths +1
-      } else if(check_equal_layers) {
-        if(!is.na(widths)) {
-          widths <- s$widths
-        } else {
-          if(length(widths)!=length(s$widths)) unequal_layers <- TRUE
-        }
-      }
-      
-      if(any(is.na(s$clay))) {
-        mis_clay <- mis_clay + 1
-        if(fill_missing) s$clay[is.na(s$clay)] <- default_values["clay"]
-      }
-      if(any(is.na(s$sand))) {
-        mis_sand <- mis_sand + 1
-        if(fill_missing) s$sand[is.na(s$sand)] <- default_values["sand"]
-      }
-      if(any(is.na(s$bd))) {
-        mis_bd <- mis_bd + 1
-        if(fill_missing) s$bd[is.na(s$bd)] <- default_values["bd"]
-      }
-      if(any(is.na(s$rfc))) {
-        mis_rfc <- mis_rfc + 1
-        if(fill_missing) s$rfc[is.na(s$rfc)] <- default_values["rfc"]
-      } else {
-        if(any(s$rfc>=100)) rfc_over_100 <-TRUE
-      }
-      x$soil[[i]] <- s
-    }
-  }
-  if(progress) {
-    cli::cli_progress_done()
-  }
-  if(unequal_layers) cli::cli_alert_warning("Unequal number of layers were detected.")
-  if(rfc_over_100) cli::cli_alert_warning("At least one soil with rfc values >= 100%.")
-  if(!fill_missing) {
-    if(mis_widths>0) cli::cli_alert_warning(paste0("Missing 'widths' values detected for ", mis_clay, " locations (", round(100*mis_widths/ntarget,1),"%)."))
-    if(mis_clay>0) cli::cli_alert_warning(paste0("Missing 'clay' values detected for ", mis_clay, " locations (", round(100*mis_clay/ntarget,1),"%)."))
-    if(mis_sand>0) cli::cli_alert_warning(paste0("Missing 'sand' values detected for ", mis_sand, " locations (", round(100*mis_sand/ntarget,1),"%)."))
-    if(mis_bd>0) cli::cli_alert_warning(paste0("Missing 'bd' values detected for ", mis_bd, " locations (", round(100*mis_bd/ntarget,1),"%)."))
-    if(mis_rfc>0) cli::cli_alert_warning(paste0("Missing 'rfc' values detected for ", mis_rfc, " locations (", round(100*mis_rfc/ntarget,1),"%)."))
-  } else {
-    if(mis_widths>0) cli::cli_alert_warning(paste0("Missing 'widths' values detected for ", mis_clay, " locations (", round(100*mis_widths/ntarget,1),"%) and cannot be imputed!"))
-    if(mis_clay>0) cli::cli_alert_info(paste0("Default 'clay' values assigned for ", mis_clay, " locations (", round(100*mis_clay/ntarget,1),"%)."))
-    if(mis_sand>0) cli::cli_alert_info(paste0("Default 'sand' values assigned for ", mis_sand, " locations (", round(100*mis_sand/ntarget,1),"%)."))
-    if(mis_bd>0) cli::cli_alert_info(paste0("Default 'bd' values assigned for ", mis_bd, " locations (", round(100*mis_bd/ntarget,1),"%)."))
-    if(mis_rfc>0) cli::cli_alert_info(paste0("Default 'rfc' values assigned for ", mis_rfc, " locations (", round(100*mis_rfc/ntarget,1),"%)."))
-  }
-  if(mis_clay==0 && mis_bd==0 && mis_rfc ==0 && mis_sand==0) cli::cli_alert_info("No missing values detected in key soil attributes.")
-  if(fill_missing) return(x)
-}
-
