@@ -36,6 +36,7 @@ const int WBCOM_BaseflowBalance = 25;
 const int WBCOM_ChannelExport = 26;
 const int WBCOM_WatershedExport = 27;
 const int WBCOM_Interception = 28;
+const int WBCOM_NegativeAquiferCorrection = 29;
 
 const int STCOM_LAI = 0;
 const int STCOM_LAIherb = 1;
@@ -46,6 +47,23 @@ const int STCOM_Cm = 5;
 const int STCOM_LgroundPAR = 6;
 const int STCOM_LgroundSWR = 7;
 
+const int FHCOM_Loading_overstory = 0;
+const int FHCOM_Loading_understory = 1;
+const int FHCOM_CFMC_overstory = 2;
+const int FHCOM_CFMC_understory = 3;
+const int FHCOM_DFMC = 4;
+const int FHCOM_ROS_surface = 5;
+const int FHCOM_I_b_surface = 6;
+const int FHCOM_t_r_surface = 7;
+const int FHCOM_FL_surface = 8;
+const int FHCOM_Ic_ratio = 9;
+const int FHCOM_ROS_crown = 10;
+const int FHCOM_I_b_crown = 11;
+const int FHCOM_t_r_crown = 12;
+const int FHCOM_FL_crown = 13;
+const int FHCOM_SFP = 14;
+const int FHCOM_CFP = 15;
+
 const int CBCOM_GrossPrimaryProduction = 0;
 const int CBCOM_MaintenanceRespiration = 1;
 const int CBCOM_SynthesisRespiration = 2;
@@ -57,71 +75,6 @@ const int BBCOM_PlantBalance = 2;
 const int BBCOM_MortalityLoss = 3;
 const int BBCOM_CohortBalance = 4;
 
-// [[Rcpp::export("drainageCells")]]
-IntegerVector drainageCells(List queenNeigh, List waterQ, int iCell) {
-  IntegerVector cells = IntegerVector::create(iCell);
-  IntegerVector neighbors = Rcpp::as<Rcpp::IntegerVector>(queenNeigh[iCell-1]);
-  int n = neighbors.size();
-  for(int i=0;i<n;i++) {
-    int nc = neighbors[i];
-    IntegerVector ni = Rcpp::as<Rcpp::IntegerVector>(queenNeigh[nc-1]);
-    NumericVector qi = Rcpp::as<Rcpp::NumericVector>(waterQ[nc-1]);
-    for(int j=0;j<ni.size();j++) {
-      if((ni[j]==iCell) && (qi[j]>0.0)) {
-        IntegerVector nicells = drainageCells(queenNeigh, waterQ, nc);
-        for(int k=0;k<nicells.size();k++) {
-          bool inBag = false;
-          for(int l=0;l<cells.size();l++) {
-            if(cells[l]==nicells[k]) inBag = true;
-          }
-          if(!inBag) cells.push_back(nicells[k]);
-        }
-      }
-    }
-  }
-  return(cells);
-}
-
-// [[Rcpp::export(".getTrackSpeciesTranspiration")]]
-NumericVector getTrackSpeciesTranspiration( NumericVector trackSpecies, NumericVector Eplant, DataFrame x) {
-  int nTrackSpecies = trackSpecies.size();
-  NumericVector Eplantsp(nTrackSpecies, 0.0);
-  NumericVector SP = x["SP"];
-  int nCoh = SP.size();
-  int ts;
-  for(int its =0;its<nTrackSpecies;its++) {
-    ts = trackSpecies[its];
-    for(int i=0;i<nCoh;i++) {
-      if(SP[i]==ts) {
-        Eplantsp[its] += Eplant[i];
-      }
-    }
-  }
-  return(Eplantsp);
-}
-
-// [[Rcpp::export(".getTrackSpeciesDDS")]]
-NumericVector getTrackSpeciesDDS(NumericVector trackSpecies, NumericVector DDS, DataFrame x) {
-  int nTrackSpecies = trackSpecies.size();
-  NumericVector DDSsp(nTrackSpecies, 0.0);
-  NumericVector LAI = x["LAI"];
-  NumericVector SP = x["SP"];
-  int nCoh = LAI.size();
-  int ts;
-  double laiSum;
-  for(int its =0;its<nTrackSpecies;its++) {
-    ts = trackSpecies[its];
-    laiSum = 0.0;
-    for(int i=0;i<nCoh;i++) {
-      if(SP[i]==ts) {
-        DDSsp[its] += DDS[i]*LAI[i];
-        laiSum +=LAI[i];
-      }
-    }
-    DDSsp = DDSsp/laiSum;
-  }
-  return(DDSsp);
-}
 // [[Rcpp::export(".copySnowpackToSoil")]]
 void copySnowpackToSoil(List y) {
   CharacterVector lct = y["land_cover_type"];
@@ -165,9 +118,9 @@ void copyStateFromResults(List y, List localResults) {
 
 // [[Rcpp::export(".createDayOutput")]]
 List createDayOutput(int nX, 
-                     bool standSummary, bool carbonBalanceSummary, bool biomassBalanceSummary) {
+                     bool standSummary, bool fireHazardSummary, bool carbonBalanceSummary, bool biomassBalanceSummary) {
 
-  int ncol = 29;
+  int ncol = 30;
   List out(ncol);
   CharacterVector colnames(ncol);
   for(int i = 0; i<ncol; i++) out[i] = NumericVector(nX, 0.0);
@@ -200,7 +153,8 @@ List createDayOutput(int nX,
   colnames[WBCOM_BaseflowBalance] = "BaseflowBalance";
   colnames[WBCOM_ChannelExport] = "ChannelExport";
   colnames[WBCOM_WatershedExport] = "WatershedExport";
-
+  colnames[WBCOM_NegativeAquiferCorrection] = "NegativeAquiferCorrection";
+  
   out.attr("names") = colnames;
 
   DataFrame waterBalance(out);
@@ -225,6 +179,31 @@ List createDayOutput(int nX,
     DataFrame stand(out_stand);
     l.push_back(stand, "WatershedStand");
   }
+  if(fireHazardSummary) {
+    int ncol_fire = 16;
+    List out_fire(ncol_fire);
+    CharacterVector colnames_fire(ncol_fire);
+    for(int i = 0; i<ncol_fire; i++) out_fire[i] = NumericVector(nX, NA_REAL);
+    colnames_fire[FHCOM_Loading_overstory] = "Loading_overstory";
+    colnames_fire[FHCOM_Loading_understory] = "Loading_understory";
+    colnames_fire[FHCOM_CFMC_overstory] = "CFMC_overstory";
+    colnames_fire[FHCOM_CFMC_understory] = "CFMC_understory";
+    colnames_fire[FHCOM_DFMC] = "DFMC";
+    colnames_fire[FHCOM_ROS_surface] = "ROS_surface";
+    colnames_fire[FHCOM_I_b_surface] = "I_b_surface";
+    colnames_fire[FHCOM_t_r_surface] = "t_r_surface";
+    colnames_fire[FHCOM_FL_surface] = "FL_surface";
+    colnames_fire[FHCOM_Ic_ratio] = "Ic_ratio";
+    colnames_fire[FHCOM_ROS_crown] = "ROS_crown";
+    colnames_fire[FHCOM_I_b_crown] = "I_b_crown";
+    colnames_fire[FHCOM_t_r_crown] = "t_r_crown";
+    colnames_fire[FHCOM_FL_crown] = "FL_crown";
+    colnames_fire[FHCOM_SFP] = "SFP";
+    colnames_fire[FHCOM_CFP] = "CFP";
+    out_fire.attr("names") = colnames_fire;
+    DataFrame fire(out_fire);
+    l.push_back(fire, "WatershedFireHazard");
+  }
   if(carbonBalanceSummary) {
     int ncol_cb = 4;
     List out_cb(ncol_cb);
@@ -267,10 +246,12 @@ void resetWaterBalanceDayOutput(DataFrame outWB) {
 
 // [[Rcpp::export(".fcpp_landunit_day")]]
 List fcpp_landunit_day(List xi, String model, CharacterVector date, List internalCommunication, 
-                       bool standSummary, bool carbonBalanceSummary, bool biomassBalanceSummary) {
+                       bool standSummary, bool fireHazardSummary, bool carbonBalanceSummary, bool biomassBalanceSummary) {
   List res;
   List x = xi["x"];
   List control  = x["control"];
+  //This forces fire hazard estimation
+  control["fireHazardResults"] = fireHazardSummary;
   String transpirationMode = control["transpirationMode"];
   CharacterVector classString = x.attr("class");
   NumericVector meteovec = xi["meteovec"];
@@ -316,6 +297,9 @@ List fcpp_landunit_day(List xi, String model, CharacterVector date, List interna
       if(standSummary && spwbOut.containsElementNamed("Stand")) {
         res.push_back(clone(as<NumericVector>(spwbOut["Stand"])),"Stand");
       }
+      if(fireHazardSummary && spwbOut.containsElementNamed("FireHazard")) {
+        res.push_back(clone(as<NumericVector>(spwbOut["FireHazard"])),"FireHazard");
+      }
       if(model=="growth") {
         List growthOut;
         if (transpirationMode=="Granier"){
